@@ -140,7 +140,7 @@ func TestServiceConsumer(t *testing.T) {
 		},
 		Spec: v1.AppInstanceSpec{
 			Image: image.ID,
-			Permissions: []v1.Permissions{{
+			GrantedPermissions: []v1.Permissions{{
 				ServiceName: "producer.default",
 				Rules: []v1.PolicyRule{{
 					PolicyRule: rbacv1.PolicyRule{
@@ -904,7 +904,7 @@ func TestDeployParam(t *testing.T) {
 		t.Fatal(err)
 	}
 
-	_, err = appDef.Args()
+	_, err = appDef.ToParamSpec()
 	if err != nil {
 		t.Fatal(err)
 	}
@@ -916,9 +916,9 @@ func TestDeployParam(t *testing.T) {
 		},
 		Spec: v1.AppInstanceSpec{
 			Image: image.ID,
-			DeployArgs: map[string]any{
+			DeployArgs: v1.NewGenericMap(map[string]any{
 				"someInt": 5,
-			},
+			}),
 		},
 	})
 	if err != nil {
@@ -1638,9 +1638,9 @@ func TestEnforcedQuota(t *testing.T) {
 		return kclient.Update(ctx, obj) == nil
 	})
 
-	// Run a simple app.
-	image, err := c.AcornImageBuild(ctx, "./testdata/simple/Acornfile", &client.AcornImageBuildOptions{
-		Cwd: "./testdata/volume",
+	// Run a scaled app.
+	image, err := c.AcornImageBuild(ctx, "./testdata/scaled/Acornfile", &client.AcornImageBuildOptions{
+		Cwd: "./testdata/scaled",
 	})
 	if err != nil {
 		t.Fatal(err)
@@ -1668,7 +1668,7 @@ func TestEnforcedQuota(t *testing.T) {
 	if err != nil {
 		t.Fatal(err)
 	}
-	assert.Equal(t, quotaRequest.Spec.Resources.Containers, 1)
+	assert.Equal(t, 2, quotaRequest.Spec.Resources.Containers)
 
 	// Update the status of the QuotaRequest to communicate readiness.
 	quotaRequest.Status = adminv1.QuotaRequestInstanceStatus{
@@ -1766,8 +1766,8 @@ func TestAutoUpgradeLocalImage(t *testing.T) {
 	}
 
 	// Deploy the app
-	imageSource := imagesource.NewImageSource("", "", []string{"mylocalimage"}, []string{}, nil, true)
-	appImage, _, err := imageSource.GetImageAndDeployArgs(ctx, c)
+	imageSource := imagesource.NewImageSource("", "", "", []string{"mylocalimage"}, nil, true)
+	appImage, _, _, err := imageSource.GetImageAndDeployArgs(ctx, c)
 	if err != nil {
 		t.Fatal(err)
 	}
