@@ -42,8 +42,31 @@ icon: "./icon"
 	assert.Equal(t, "./icon", appSpec.Icon)
 }
 
+func TestOldSyntax(t *testing.T) {
+	_, err := NewAppDefinition([]byte(`args: name: string | *"hi"
+containers: foo: image: args.name
+`))
+	require.Error(t, err)
+
+	appImage, err := NewAppDefinition([]byte(`//acorn:amlv0
+args: name: string | *"hi"
+containers: foo: image: args.name
+`))
+	if err != nil {
+		t.Fatal(err)
+	}
+
+	appSpec, err := appImage.AppSpec()
+	if err != nil {
+		t.Fatal(err)
+	}
+
+	assert.Equal(t, "hi", appSpec.Containers["foo"].Image)
+}
+
 func TestProfilesImplicitArgs(t *testing.T) {
 	appImage, err := NewAppDefinition([]byte(`profiles: a: {}, profiles: d: {}
+std.debug("debugs", args.profiles)
 	if std.contains(args.profiles, "d") {
 		containers: foo: {}
 	}
@@ -51,17 +74,13 @@ func TestProfilesImplicitArgs(t *testing.T) {
 	if err != nil {
 		t.Fatal(err)
 	}
-	appDef, args, err := appImage.WithArgs(nil, []string{"a", "b?", "c?", "d?"})
-	if err != nil {
-		t.Fatal(err)
-	}
+	appDef := appImage.WithArgs(nil, []string{"a", "b?", "c?", "d?"})
 
 	appSpec, err := appDef.AppSpec()
 	if err != nil {
 		t.Fatal(err)
 	}
 
-	assert.Equal(t, []any{"a", "d"}, args["profiles"])
 	assert.Equal(t, []string{"a", "b?", "c?", "d?"}, appDef.profiles)
 	assert.Contains(t, appSpec.Containers, "foo")
 }
@@ -71,13 +90,13 @@ func TestDefaultProfiles(t *testing.T) {
 	if err != nil {
 		t.Fatal(err)
 	}
-	args, err := appImage.Args()
+	args, err := appImage.ToParamSpec()
 	if err != nil {
 		t.Fatal(err)
 	}
 
 	assert.Len(t, args.Profiles, 0)
-	assert.Len(t, args.Params, 0)
+	assert.Len(t, args.Args, 0)
 }
 
 func TestDescription(t *testing.T) {
@@ -149,8 +168,6 @@ routers: {
 	}
 
 	assert.Equal(t, v1.Router{
-		Labels:      map[string]string{},
-		Annotations: map[string]string{},
 		Routes: []v1.Route{
 			{
 				Path:              "/short",
@@ -168,8 +185,6 @@ routers: {
 	}, spec.Routers["slice"])
 
 	assert.Equal(t, v1.Router{
-		Labels:      map[string]string{},
-		Annotations: map[string]string{},
 		Routes: []v1.Route{
 			{
 				Path:              "/bar/exact",
@@ -339,8 +354,8 @@ acorns: {
 	assert.Equal(t, "", buildSpec.Acorns["afull"].Image)
 	assert.Equal(t, "sub/dir2", buildSpec.Acorns["afull"].Build.Context)
 	assert.Equal(t, "sub/dir3/Acornfile", buildSpec.Acorns["afull"].Build.Acornfile)
-	assert.Equal(t, "value", buildSpec.Acorns["afull"].Build.BuildArgs["key"])
-	assert.Equal(t, map[string]any{"key3": "value3"}, buildSpec.Acorns["afull"].Build.BuildArgs["key2"])
+	assert.Equal(t, "value", buildSpec.Acorns["afull"].Build.BuildArgs.GetData()["key"])
+	assert.Equal(t, map[string]any{"key3": "value3"}, buildSpec.Acorns["afull"].Build.BuildArgs.GetData()["key2"])
 	assert.Equal(t, "done", buildSpec.Acorns["anone"].Image)
 }
 
@@ -918,7 +933,8 @@ containers: {
 	assert.Equal(t, int32(80), appSpec.Containers["s"].Sidecars["right2"].Ports[0].Port)
 	assert.Equal(t, appSpec.Containers["s"].Sidecars["right2"].Ports[0].Protocol, v1.Protocol(""))
 
-	assert.Equal(t, int32(12), appSpec.Containers["s"].Sidecars["right3"].Ports[0].Port)
+	assert.Equal(t, int32(0), appSpec.Containers["s"].Sidecars["right3"].Ports[0].Port)
+	assert.Equal(t, int32(12), appSpec.Containers["s"].Sidecars["right3"].Ports[0].TargetPort)
 	assert.Equal(t, appSpec.Containers["s"].Sidecars["right3"].Ports[0].Protocol, v1.Protocol(""))
 	assert.Equal(t, int32(80), appSpec.Containers["s"].Sidecars["right3"].Ports[1].Port)
 	assert.Equal(t, appSpec.Containers["s"].Sidecars["right3"].Ports[1].Protocol, v1.Protocol(""))
@@ -1097,8 +1113,6 @@ images: {
 	}
 
 	assert.Equal(t, &v1.BuilderSpec{
-		Services: map[string]v1.AcornBuilderSpec{},
-		Jobs:     map[string]v1.ContainerImageBuilderSpec{},
 		Containers: map[string]v1.ContainerImageBuilderSpec{
 			"image": {
 				Image: "image-image",
@@ -1110,28 +1124,22 @@ images: {
 			},
 			"build": {
 				Build: &v1.Build{
-					BuildArgs:          map[string]string{},
-					AdditionalContexts: map[string]string{},
-					Context:            ".",
-					Dockerfile:         "Dockerfile",
+					Context:    ".",
+					Dockerfile: "Dockerfile",
 				},
 				Sidecars: map[string]v1.ContainerImageBuilderSpec{
 					"side": {
 						Build: &v1.Build{
-							BuildArgs:          map[string]string{},
-							AdditionalContexts: map[string]string{},
-							Context:            ".",
-							Dockerfile:         "Dockerfile",
+							Context:    ".",
+							Dockerfile: "Dockerfile",
 						},
 					},
 				},
 			},
 			"buildcontext": {
 				Build: &v1.Build{
-					BuildArgs:          map[string]string{},
-					AdditionalContexts: map[string]string{},
-					Context:            ".",
-					Dockerfile:         "Dockerfile",
+					Context:    ".",
+					Dockerfile: "Dockerfile",
 					ContextDirs: map[string]string{
 						"/var/tmp": "./foo/bar",
 					},
@@ -1139,10 +1147,8 @@ images: {
 				Sidecars: map[string]v1.ContainerImageBuilderSpec{
 					"side": {
 						Build: &v1.Build{
-							BuildArgs:          map[string]string{},
-							AdditionalContexts: map[string]string{},
-							Context:            ".",
-							Dockerfile:         "Dockerfile",
+							Context:    ".",
+							Dockerfile: "Dockerfile",
 							ContextDirs: map[string]string{
 								"/var/tmp": "./foo/bar",
 							},
@@ -1178,7 +1184,6 @@ images: {
 		Images: map[string]v1.ImageBuilderSpec{
 			"ibuild": {
 				AcornBuild: &v1.AcornBuild{
-					BuildArgs: v1.GenericMap{},
 					Context:   ".",
 					Acornfile: "Acornfile",
 				},
@@ -1187,7 +1192,6 @@ images: {
 				Image: "images-image-image",
 			},
 		},
-		Acorns: map[string]v1.AcornBuilderSpec{},
 	}, buildSpec)
 
 	app := appImage.WithImageData(v1.ImagesData{
@@ -1284,6 +1288,7 @@ containers: {
 
 func TestVolumes(t *testing.T) {
 	appImage, err := NewAppDefinition([]byte(`
+args: foo: "baz"
 containers: {
   s: {
     sidecars: left: {
@@ -1346,10 +1351,7 @@ volumes: {
 		Images: nil,
 	})
 
-	appImage, _, err = appImage.WithArgs(map[string]any{"foo": "bar"}, nil)
-	if err != nil {
-		t.Fatal(err)
-	}
+	appImage = appImage.WithArgs(map[string]any{"foo": "bar"}, nil)
 
 	appSpec, err := appImage.AppSpec()
 	if err != nil {
@@ -1445,17 +1447,19 @@ secrets: {
 	}
 
 	assert.Equal(t, v1.Secret{
-		Type:        "opaque",
-		Labels:      map[string]string{},
-		Annotations: map[string]string{},
+		Type: "opaque",
 		Data: map[string]string{
 			"username": "bardata",
 		},
 	}, appSpec.Secrets["explicit"])
 	assert.Equal(t, v1.Secret{
-		Type:        "basic",
-		Labels:      map[string]string{},
-		Annotations: map[string]string{},
+		Type: "basic",
+		Params: v1.NewGenericMap(map[string]any{
+			"passwordCharacters": "ABCDEFGHIJKLMNOPQRSTUVWXYZabcdefghijklmnopqrstuvwxyz0123456789!#$%^&*_-=+",
+			"passwordLength":     int64(16),
+			"usernameCharacters": "ABCDEFGHIJKLMNOPQRSTUVWXYZabcdefghijklmnopqrstuvwxyz0123456789!#$%^&*_-=+",
+			"usernameLength":     int64(8),
+		}),
 		Data: map[string]string{
 			"username": "bardata",
 			"password": "barpass",
@@ -1468,10 +1472,7 @@ secrets: {
 		Type: "opaque",
 	}, appSpec.Secrets["file-implicit"])
 	assert.Equal(t, v1.Secret{
-		Type:        "opaque",
-		Labels:      map[string]string{},
-		Annotations: map[string]string{},
-		Data:        map[string]string{},
+		Type: "opaque",
 	}, appSpec.Secrets["dirs-merge"])
 	assert.Equal(t, v1.Secret{
 		Type: "opaque",
@@ -1518,12 +1519,9 @@ containers: c: image: args.image
 
 	assert.Equal(t, "foo-hash", appSpec.Containers["c"].Image)
 
-	app, _, err = app.WithArgs(map[string]any{
+	app = app.WithArgs(map[string]any{
 		"image": "not-foo",
 	}, nil)
-	if err != nil {
-		t.Fatal(err)
-	}
 
 	_, err = app.AppSpec()
 	assert.ErrorContains(t, err, "failed to find image for container [c] in Acornfile, you may need to define the image/build in the images section of the Acornfile")
@@ -1591,10 +1589,7 @@ for i in std.range(1,args.scale+1) {
 	}
 
 	app = app.WithImageData(*image)
-	devApp, _, err := app.WithArgs(map[string]any{"scale": 2}, nil)
-	if err != nil {
-		t.Fatal(err)
-	}
+	devApp := app.WithArgs(map[string]any{"scale": 2}, nil)
 
 	appSpec, err := devApp.AppSpec()
 	if err != nil {
@@ -1681,10 +1676,7 @@ images: cimage: image: "container-dev"
 	}
 
 	app = app.WithImageData(*image)
-	devApp, _, err := app.WithArgs(nil, []string{"devMode"})
-	if err != nil {
-		t.Fatal(err)
-	}
+	devApp := app.WithArgs(nil, []string{"devMode"})
 
 	appSpec, err := devApp.AppSpec()
 	if err != nil {
@@ -1848,41 +1840,35 @@ func TestBuildProfileParameters(t *testing.T) {
 args: {
   foo: "three"
 }
-profiles: one: foo: string | *"one"
-profiles: two: foo: string | *"two"
-containers: foo: build: buildArgs: one: args.foo
+profiles: one: foo: "from one"
+profiles: two: foo: "from two"
+containers: foo: build: buildArgs: foo: args.foo
 `
 	def, err := NewAppDefinition([]byte(acornCue))
 	if err != nil {
 		t.Fatal(err)
 	}
 
-	_, _, err = def.WithArgs(map[string]any{}, []string{"one", "two", "three"})
+	_, err = def.WithArgs(map[string]any{}, []string{"one", "two", "three"}).AppSpec()
 	assert.Equal(t, "failed to find profile three", err.Error())
 
-	def, _, err = def.WithArgs(map[string]any{}, []string{"one", "two", "three?"})
-	if err != nil {
-		t.Fatal(err)
-	}
+	def = def.WithArgs(map[string]any{}, []string{"one", "two", "three?"})
 
 	buildSpec, err := def.BuilderSpec()
 	if err != nil {
 		t.Fatal(err)
 	}
 
-	assert.Equal(t, "one", buildSpec.Containers["foo"].Build.BuildArgs["one"])
+	assert.Equal(t, "from two", buildSpec.Containers["foo"].Build.BuildArgs["foo"])
 
-	def, _, err = def.WithArgs(map[string]any{}, []string{"two", "one"})
-	if err != nil {
-		t.Fatal(err)
-	}
+	def = def.WithArgs(map[string]any{}, []string{"two", "one"})
 
 	buildSpec, err = def.BuilderSpec()
 	if err != nil {
 		t.Fatal(err)
 	}
 
-	assert.Equal(t, "two", buildSpec.Containers["foo"].Build.BuildArgs["one"])
+	assert.Equal(t, "from one", buildSpec.Containers["foo"].Build.BuildArgs["foo"])
 }
 
 func TestBuildParameters(t *testing.T) {
@@ -1897,12 +1883,9 @@ containers: foo: build: buildArgs: one: args.foo
 		t.Fatal(err)
 	}
 
-	def, _, err = def.WithArgs(map[string]any{
+	def = def.WithArgs(map[string]any{
 		"foo": "two",
 	}, nil)
-	if err != nil {
-		t.Fatal(err)
-	}
 
 	buildSpec, err := def.BuilderSpec()
 	if err != nil {
@@ -2029,8 +2012,10 @@ acorns: first: {
 		Name:  "c",
 		Value: "d",
 	}, acorn.Environment[1])
-	assert.Equal(t, v1.GenericMap{
-		"foo": int64(12),
+	assert.Equal(t, &v1.GenericMap{
+		Data: map[string]any{
+			"foo": int64(12),
+		},
 	}, acorn.DeployArgs)
 	assert.Equal(t, []string{"abc", "def"}, acorn.Profiles)
 }
@@ -2097,9 +2082,9 @@ acorns: first: {
 	assert.Equal(t, &v1.AcornBuild{
 		Context:   "abc",
 		Acornfile: "other/Acornfile",
-		BuildArgs: v1.GenericMap{
+		BuildArgs: v1.NewGenericMap(map[string]any{
 			"a": "b",
-		},
+		}),
 	}, acorn.Build)
 	assert.Equal(t, v1.PortBinding{
 		Hostname:   "example.com",
@@ -2154,7 +2139,7 @@ acorns: first: {
 
 	assert.Equal(t, v1.PortBinding{
 		Hostname:          "example.com",
-		Port:              80,
+		Port:              0,
 		TargetPort:        80,
 		TargetServiceName: "asdf",
 	}, acorn.Publish[0])
@@ -2231,9 +2216,11 @@ services: job: {
 			Target: "sbar",
 		},
 	}, svc.Secrets)
-	assert.Equal(t, v1.GenericMap{
-		"foo": map[string]any{
-			"hi": "bye",
+	assert.Equal(t, &v1.GenericMap{
+		Data: map[string]any{
+			"foo": map[string]any{
+				"hi": "bye",
+			},
 		},
 	}, svc.Data)
 
@@ -2258,8 +2245,10 @@ services: job: {
 	assert.Equal(t, int64(44000000000), *acorn.Memory[""])
 	assert.Equal(t, "foo", acorn.Environment[0].Name)
 	assert.Equal(t, "bar", acorn.Environment[0].Value)
-	assert.Equal(t, v1.GenericMap{
-		"key": "value",
+	assert.Equal(t, &v1.GenericMap{
+		Data: map[string]any{
+			"key": "value",
+		},
 	}, acorn.ServiceArgs)
 
 	job := appSpec.Services["job"]
@@ -2487,10 +2476,11 @@ profiles: foo: {}
 		t.Fatal(err)
 	}
 
-	_, _, err = def.WithArgs(nil, []string{"foo"})
+	_, err = def.WithArgs(nil, []string{"foo"}).AppSpec()
 	assert.Nil(t, err)
 
-	_, _, err = def.WithArgs(nil, []string{"missing"})
+	_, err = def.WithArgs(nil, []string{"missing"}).AppSpec()
+	require.Error(t, err)
 	assert.Equal(t, "failed to find profile missing", err.Error())
 }
 
@@ -2550,7 +2540,7 @@ localData: { r: list.Range(1,2,3) }
 
 	_, err := NewAppDefinition([]byte(acornCue))
 	assert.NotNil(t, err)
-	assert.Contains(t, err.Error(), "import keyword is not")
+	assert.Contains(t, err.Error(), "key not found \"import\": Acornfile:2:1")
 }
 
 func TestNoPackage(t *testing.T) {
@@ -2569,9 +2559,11 @@ containers: foo: image: localData.data
 localData: {
     data: echo("hi")
 	data: "hi"
-	echo: {
-		args: [_]
-		out: args[0]
+	echo: function {
+		args: {
+			first: string
+		}
+		return: args.first
 	}
 }
 `
@@ -2591,47 +2583,31 @@ localData: {
 
 func TestStdMissing(t *testing.T) {
 	data := `
-let foo = std.toyaml({})
+foo : std.toyaml({})
 `
 
 	_, err := NewAppDefinition([]byte(data))
-	assert.NotNil(t, err)
-	assert.Contains(t, err.Error(), "invalid reference to std.toyaml, closest matches [toYAML fromYAML trim]")
+	require.Error(t, err)
+	assert.Contains(t, err.Error(), "key not found \"toyaml\": Acornfile:2:11")
 }
 
 func TestArgsTopCondition(t *testing.T) {
 	data := `
-let foo = true
-if foo {
 	args: {
 		// test comment
 		test: "adsf",
 	}
-}
 `
 	appDef, err := NewAppDefinition([]byte(data))
 	if err != nil {
 		t.Fatal(err)
 	}
-	args, err := appDef.Args()
+	args, err := appDef.ToParamSpec()
 	if err != nil {
 		t.Fatal(err)
 	}
 
-	assert.Equal(t, "test comment", args.Params[0].Description)
-}
-
-func TestArgsRejectConditions(t *testing.T) {
-	data := `
-args: {
-	if foo {
-		test: "adsf",
-	}
-}
-`
-	_, err := NewAppDefinition([]byte(data))
-	assert.NotNil(t, err)
-	assert.Contains(t, err.Error(), "comprehension (if) should not be used inside the args and profiles fields")
+	assert.Equal(t, "test comment", args.Args[0].Description)
 }
 
 func getVals(t *testing.T, appDef *AppDefinition) map[string]any {
@@ -2656,36 +2632,10 @@ func getVals(t *testing.T, appDef *AppDefinition) map[string]any {
 	return data
 }
 
-func TestNoConditionInProfile(t *testing.T) {
-	data := `
-profiles: default: {
-	if true {
-		a: "b"
-	}
-}
-`
-	_, err := NewAppDefinition([]byte(data))
-	assert.NotNil(t, err)
-	assert.Contains(t, err.Error(), "comprehension (if) should not be used inside the args and profiles fields")
-}
-
-func TestNoConditionInProfileTop(t *testing.T) {
-	data := `
-profiles: {
-	if true {
-		default: {
-			a: "b"
-		}
-	}
-}
-`
-	_, err := NewAppDefinition([]byte(data))
-	assert.NotNil(t, err)
-	assert.Contains(t, err.Error(), "comprehension (if) should not be used inside the args and profiles fields")
-}
-
 func TestProfileDefaultValues(t *testing.T) {
 	data := `
+args: a: "unmatched"
+args: c: "unmatched"
 containers: default: files: a: std.toJSON(args)
 // include some non-alpha characters
 profiles: "foo - bar": {
@@ -2697,18 +2647,17 @@ profiles: "foo - bar": {
 		t.Fatal(err)
 	}
 
-	defaultAppDef, args, err := appDef.WithArgs(nil, []string{"foo - bar"})
-	if err != nil {
-		t.Fatal(err)
-	}
-	assert.Equal(t, map[string]any{"a": "b", "profiles": []any{"foo - bar"}}, args)
-	assert.Equal(t, map[string]any{"a": "b", "dev": false, "autoUpgrade": false, "profiles": []any{"foo - bar"}}, getVals(t, defaultAppDef))
+	defaultAppDef := appDef.WithArgs(nil, []string{"foo - bar"})
 
-	appDef, args, err = appDef.WithArgs(map[string]any{"a": "c", "c": "d"}, []string{"foo - bar"})
-	if err != nil {
-		t.Fatal(err)
-	}
-	assert.Equal(t, map[string]any{"a": "c", "c": "d", "profiles": []any{"foo - bar"}}, args)
+	assert.Equal(t, map[string]any{
+		"a":           "b",
+		"c":           "unmatched",
+		"dev":         false,
+		"autoUpgrade": false,
+		"profiles":    []any{"foo - bar"}},
+		getVals(t, defaultAppDef))
+
+	appDef = appDef.WithArgs(map[string]any{"a": "c", "c": "d"}, []string{"foo - bar"})
 	assert.Equal(t, map[string]any{"a": "c", "c": "d", "dev": false, "autoUpgrade": false, "profiles": []any{"foo - bar"}}, getVals(t, appDef))
 }
 
@@ -2720,9 +2669,9 @@ args: {
 	f: 6.0
 	b: true
 	bn: false
-	e: "x" | "y" | "z"
-	a: ["val"]
-	o: {}
+	e: enum("x", "y", "z") || default "x"
+	a: [string] || default ["val"]
+	o: object || default {}
 }
 containers: default: files: "a": std.toJSON(args)
 `
@@ -2759,33 +2708,13 @@ containers: default: files: "a": std.toJSON(args)
 		},
 	}
 
-	appDef, _, err = appDef.WithArgs(newValues, nil)
-	if err != nil {
-		t.Fatal(err)
-	}
+	appDef = appDef.WithArgs(newValues, nil)
 
 	newValues["e"] = "x"
 	newValues["profiles"] = []any{}
 	assert.Equal(t, newValues, getVals(t, appDef))
 }
 
-func TestErrorFriendly(t *testing.T) {
-	data := `
-foo: int
-foo: bar
-bar: baz
-baz: "h"
-`
-	_, err := NewAppDefinition([]byte(data))
-	assert.NotNil(t, err)
-	assert.Equal(t, `foo: conflicting values int and "h" (mismatched types int and string):
-    Acornfile:2:6
-    Acornfile:3:6
-    Acornfile:4:6
-    Acornfile:5:6
-`, err.Error())
-}
-
 func TestEnvValFromArg(t *testing.T) {
 	data := `
 args: a: "foo"
@@ -3003,70 +2932,26 @@ acorns: nodef: {
 	require.NoError(t, err)
 
 	autogold.Expect(&v1.AppSpec{
-		Labels:      map[string]string{},
-		Annotations: map[string]string{},
-		Containers:  map[string]v1.Container{},
-		Jobs:        map[string]v1.Container{},
-		Images:      map[string]v1.Image{},
-		Volumes:     map[string]v1.VolumeRequest{},
-		Secrets:     map[string]v1.Secret{},
+		Volumes: map[string]v1.VolumeRequest{},
+		Secrets: map[string]v1.Secret{},
 		Acorns: map[string]v1.Acorn{
 			"def": {
-				Labels:         v1.ScopedLabels{},
-				Annotations:    v1.ScopedLabels{},
-				Profiles:       []string{},
-				DeployArgs:     v1.GenericMap{},
-				Publish:        v1.PortBindings{},
-				Secrets:        v1.SecretBindings{},
-				Volumes:        v1.VolumeBindings{},
-				Links:          v1.ServiceBindings{},
-				AutoUpgrade:    valast.Addr(false).(*bool),
-				NotifyUpgrade:  valast.Addr(false).(*bool),
 				Memory:         v1.MemoryMap{"": valast.Addr(int64(1000000000)).(*int64)},
 				ComputeClasses: v1.ComputeClassMap{"": "foo"},
-				Permissions:    map[string]v1.Permissions{},
 			},
 			"nodef": {
-				Labels:         v1.ScopedLabels{},
-				Annotations:    v1.ScopedLabels{},
-				Profiles:       []string{},
-				DeployArgs:     v1.GenericMap{},
-				Publish:        v1.PortBindings{},
-				Secrets:        v1.SecretBindings{},
-				Volumes:        v1.VolumeBindings{},
-				Links:          v1.ServiceBindings{},
-				AutoUpgrade:    valast.Addr(false).(*bool),
-				NotifyUpgrade:  valast.Addr(false).(*bool),
 				Memory:         v1.MemoryMap{"foo": valast.Addr(int64(1000000000)).(*int64)},
 				ComputeClasses: v1.ComputeClassMap{"foo": "bar"},
-				Permissions:    map[string]v1.Permissions{},
 			},
 		},
-		Routers: map[string]v1.Router{},
 		Services: map[string]v1.Service{
 			"sdef": {
-				Labels:         v1.ScopedLabels{},
-				Annotations:    v1.ScopedLabels{},
-				ServiceArgs:    v1.GenericMap{},
-				Secrets:        v1.SecretBindings{},
-				Links:          v1.ServiceBindings{},
-				AutoUpgrade:    valast.Addr(false).(*bool),
-				NotifyUpgrade:  valast.Addr(false).(*bool),
 				Memory:         v1.MemoryMap{"": valast.Addr(int64(1000000000)).(*int64)},
 				ComputeClasses: v1.ComputeClassMap{"": "foo"},
-				Permissions:    map[string]v1.Permissions{},
 			},
 			"snodef": {
-				Labels:         v1.ScopedLabels{},
-				Annotations:    v1.ScopedLabels{},
-				ServiceArgs:    v1.GenericMap{},
-				Secrets:        v1.SecretBindings{},
-				Links:          v1.ServiceBindings{},
-				AutoUpgrade:    valast.Addr(false).(*bool),
-				NotifyUpgrade:  valast.Addr(false).(*bool),
 				Memory:         v1.MemoryMap{"foo": valast.Addr(int64(1000000000)).(*int64)},
 				ComputeClasses: v1.ComputeClassMap{"foo": "bar"},
-				Permissions:    map[string]v1.Permissions{},
 			},
 		},
 	}).Equal(t, appSpec)
@@ -3080,7 +2965,7 @@ func TestNestedScopedLabels(t *testing.T) {
 	s: {
 		labels: [
 			{
-				resourceType: "",
+				//resourceType: "",
 				resourceName: "",
 				key: "globalkey",
 				value: "x0"
@@ -3098,7 +2983,7 @@ func TestNestedScopedLabels(t *testing.T) {
 				value: "x2"
 			},
 			{
-				resourceType: "",
+				//resourceType: "",
 				resourceName: "objbar",
 				key: "acorn.io/barkey",
 				value: "x3"
