@@ -112,7 +112,15 @@ type AppUpdateOptions struct {
 	DevSessionClient    *v1.DevSessionInstanceClient
 }
 
-type LogOptions apiv1.LogOptions
+type ContainerLogsWriter interface {
+	Container(timeStamp metav1.Time, containerName, line string)
+}
+
+type LogOptions struct {
+	apiv1.LogOptions
+
+	Logger ContainerLogsWriter
+}
 
 type AppRunOptions struct {
 	Name                string
@@ -370,9 +378,10 @@ type ImageSignOptions struct {
 }
 
 type ImageVerifyOptions struct {
-	PublicKey   string              `json:"publicKeys,omitempty"`
-	Annotations map[string]string   `json:"annotations,omitempty"`
-	Auth        *apiv1.RegistryAuth `json:"auth,omitempty"`
+	PublicKey    string              `json:"publicKeys,omitempty"`
+	Annotations  map[string]string   `json:"annotations,omitempty"`
+	Auth         *apiv1.RegistryAuth `json:"auth,omitempty"`
+	NoVerifyName bool                `json:"noVerifyName,omitempty"`
 }
 
 func (o EventStreamOptions) ListOptions() *kclient.ListOptions {
@@ -445,14 +454,14 @@ func (c *DefaultClient) getRESTConfig(ctx context.Context, opts *KubeProxyAddres
 
 	data, err := json.Marshal(map[string]any{
 		"kind":       "AccessConfig",
-		"apiVersion": "account.manager.acorn.io/v1",
+		"apiVersion": "aws.account.manager.acorn.io/v1",
 		"regionName": opts.Region,
 	})
 	if err != nil {
 		return nil, err
 	}
 	// Could this be prettier
-	resp, err := client.Post(c.RESTConfig.Host+"/apis/account.manager.acorn.io/v1/accessconfigs",
+	resp, err := client.Post(c.RESTConfig.Host+"/apis/aws.account.manager.acorn.io/v1/accessconfigs",
 		"application/json", bytes.NewBuffer(data))
 	if err != nil {
 		return nil, err
