@@ -21,7 +21,7 @@ import (
 	"github.com/acorn-io/runtime/pkg/client"
 	"github.com/acorn-io/runtime/pkg/computeclasses"
 	apiv1config "github.com/acorn-io/runtime/pkg/config"
-	"github.com/acorn-io/runtime/pkg/imageallowrules"
+	"github.com/acorn-io/runtime/pkg/imagerules"
 	"github.com/acorn-io/runtime/pkg/images"
 	"github.com/acorn-io/runtime/pkg/imagesystem"
 	"github.com/acorn-io/runtime/pkg/labels"
@@ -165,41 +165,43 @@ func (s *Validator) Validate(ctx context.Context, obj runtime.Object) (result fi
 			}
 		}
 
-		imageDetails, err := s.getImageDetails(ctx, app.Namespace, app.Spec.GetProfiles(app.Status.GetDevMode()), app.Spec.DeployArgs, image)
+		imageDetails, err := s.getImageDetails(ctx, app.Namespace, app.Spec.GetProfiles(app.Status.GetDevMode()), app.Spec.DeployArgs.GetData(), image)
 		if err != nil {
 			result = append(result, field.Invalid(field.NewPath("spec", "image"), app.Spec.Image, err.Error()))
 			return
 		}
 
-		disableCheckImageAllowRules := false
-		if app.Spec.Stop != nil && *app.Spec.Stop {
-			// app was stopped, so we don't need to check image allow rules (this could prevent stopping an app if the image allow rules changed)
-			disableCheckImageAllowRules = true
-		}
-
-		if !disableCheckImageAllowRules {
-			if err := imageallowrules.CheckImageAllowed(ctx, s.client, app.Namespace, checkImage, imageDetails.AppImage.Digest, remote.WithTransport(s.transport)); err != nil {
+		if !z.Dereference(app.Spec.Stop) {
+			// App was stopped, so we don't need to check image allow rules or compute classes
+			// (this could prevent stopping an app if either of these have changed)
+			if err := imagerules.CheckImageAllowed(ctx, s.client, app.Namespace, checkImage, image, imageDetails.AppImage.Digest, remote.WithTransport(s.transport)); err != nil {
 				result = append(result, field.Forbidden(field.NewPath("spec", "image"), fmt.Sprintf("%s not allowed to run: %s", app.Spec.Image, err.Error())))
 				return
 			}
-		}
 
-		workloadsFromImage, err := s.getWorkloads(imageDetails)
-		if err != nil {
-			result = append(result, field.Invalid(field.NewPath("spec", "image"), app.Spec.Image, err.Error()))
-			return
-		}
+			workloadsFromImage, err := s.getWorkloads(imageDetails)
+			if err != nil {
+				result = append(result, field.Invalid(field.NewPath("spec", "image"), app.Spec.Image, err.Error()))
+				return
+			}
 
-		apiv1cfg, err := apiv1config.Get(ctx, s.client)
-		if err != nil {
-			result = append(result, field.Invalid(field.NewPath("config"), app.Spec.Image, err.Error()))
-			return
-		}
+			var apiv1cfg *apiv1.Config
+			apiv1cfg, err = apiv1config.Get(ctx, s.client)
+			if err != nil {
+				result = append(result, field.Invalid(field.NewPath("config"), app.Spec.Image, err.Error()))
+				return
+			}
 
-		errs := s.checkScheduling(ctx, app, project, workloadsFromImage, apiv1cfg.WorkloadMemoryDefault, apiv1cfg.WorkloadMemoryMaximum)
-		if len(errs) != 0 {
-			result = append(result, errs...)
-			return
+			errs := s.checkScheduling(ctx,
+				app,
+				project,
+				workloadsFromImage,
+				apiv1cfg.WorkloadMemoryDefault,
+				apiv1cfg.WorkloadMemoryMaximum)
+			if len(errs) != 0 {
+				result = append(result, errs...)
+				return
+			}
 		}
 
 		if err := validateVolumeClasses(ctx, s.client, app.Namespace, app.Spec, imageDetails.AppSpec, project); err != nil {
@@ -208,24 +210,24 @@ func (s *Validator) Validate(ctx context.Context, obj runtime.Object) (result fi
 		}
 
 		var imageRejectedPerms []v1.Permissions
-		imageGrantedPerms, imageRejectedPerms, err = s.imageGrants(ctx, imageDetails)
+		imageGrantedPerms, imageRejectedPerms, err = s.imageGrants(ctx, imageDetails, checkImage)
 		if err != nil {
-			result = append(result, field.Invalid(field.NewPath("spec", "permissions"), app.Spec.Permissions, err.Error()))
+			result = append(result, field.Invalid(field.NewPath("spec", "permissions"), app.Spec.GrantedPermissions, err.Error()))
 			return
 		}
 
-		if err := s.checkRequestedPermsSatisfyImagePerms(app.Namespace, imageRejectedPerms, app.Spec.Permissions); err != nil {
-			result = append(result, field.Invalid(field.NewPath("spec", "permissions"), app.Spec.Permissions, err.Error()))
+		if err := s.checkRequestedPermsSatisfyImagePerms(app.Namespace, imageRejectedPerms, app.Spec.GrantedPermissions); err != nil {
+			result = append(result, field.Invalid(field.NewPath("spec", "permissions"), app.Spec.GrantedPermissions, err.Error()))
 			return
 		}
 
 		app.Spec.ImageGrantedPermissions = imageGrantedPerms
 	}
 
-	if _, rejected, err := s.checkPermissionsForPrivilegeEscalation(ctx, app.Spec.Permissions); err != nil {
-		result = append(result, field.Invalid(field.NewPath("spec", "permissions"), app.Spec.Permissions, err.Error()))
+	if _, rejected, err := s.checkPermissionsForPrivilegeEscalation(ctx, app.Spec.GrantedPermissions); err != nil {
+		result = append(result, field.Invalid(field.NewPath("spec", "permissions"), app.Spec.GrantedPermissions, err.Error()))
 	} else if len(rejected) > 0 {
-		result = append(result, field.Invalid(field.NewPath("spec", "permissions"), app.Spec.Permissions, z.Pointer(client.ErrNotAuthorized{
+		result = append(result, field.Invalid(field.NewPath("spec", "permissions"), app.Spec.GrantedPermissions, z.Pointer(client.ErrNotAuthorized{
 			Permissions: rejected,
 		}).Error()))
 	}
@@ -561,7 +563,7 @@ func (s *Validator) checkPermissionsForPrivilegeEscalation(ctx context.Context,
 	return s.checkSARs(ctx, sars)
 }
 
-// checkScheduling must use apiv1.ComputeCLass to validate the scheduling instead of the Instance counterparts.
+// checkScheduling must use apiv1.ComputeClass to validate the scheduling instead of the Instance counterparts.
 func (s *Validator) checkScheduling(ctx context.Context, params *apiv1.App, project *v1.ProjectInstance, workloads map[string]v1.Container, specMemDefault, specMemMaximum *int64) []*field.Error {
 	var (
 		memory        = params.Spec.Memory
@@ -756,7 +758,7 @@ func (s *Validator) imageSAR(ns, imageName, imageDigest string, perms []v1.Permi
 	return
 }
 
-func (s *Validator) imageGrants(ctx context.Context, details *apiv1.ImageDetails) (granted, rejected []v1.Permissions, _ error) {
+func (s *Validator) imageGrants(ctx context.Context, details *apiv1.ImageDetails, imageNameOverride string) (granted, rejected []v1.Permissions, _ error) {
 	defer func() {
 		granted = v1.SimplifySet(granted)
 		rejected = v1.SimplifySet(rejected)
@@ -765,14 +767,19 @@ func (s *Validator) imageGrants(ctx context.Context, details *apiv1.ImageDetails
 	ns, _ := request.NamespaceFrom(ctx)
 	var sars []sarRequest
 
-	newSars, err := s.imageSAR(ns, details.AppImage.Name, details.AppImage.Digest, details.Permissions)
+	imageName := details.AppImage.Name
+	if imageNameOverride != "" {
+		imageName = imageNameOverride
+	}
+
+	newSars, err := s.imageSAR(ns, imageName, details.AppImage.Digest, details.Permissions)
 	if err != nil {
 		return nil, nil, err
 	}
 	sars = append(sars, newSars...)
 
 	for _, nested := range details.NestedImages {
-		newSars, err := s.imageSAR(ns, nested.Name, nested.Digest, nested.Permissions)
+		newSars, err := s.imageSAR(ns, nested.ImageName, nested.Digest, nested.Permissions)
 		if err != nil {
 			return nil, nil, err
 		}
@@ -813,7 +820,7 @@ func (s *Validator) resolveLocalImage(ctx context.Context, namespace, image stri
 
 func (s *Validator) getImageDetails(ctx context.Context, namespace string, profiles []string, args map[string]any, image string) (*apiv1.ImageDetails, error) {
 	details := &apiv1.ImageDetails{
-		DeployArgs:    args,
+		DeployArgs:    v1.NewGenericMap(args),
 		Profiles:      profiles,
 		IncludeNested: true,
 	}
