@@ -13,10 +13,10 @@ type Validator struct{}
 
 func (s *Validator) Validate(ctx context.Context, obj runtime.Object) (result field.ErrorList) {
 	aiar := obj.(*apiv1.ImageAllowRule)
-	if len(aiar.Images) == 0 {
+	if len(aiar.ImageSelector.NamePatterns) == 0 {
 		return append(result, field.Required(field.NewPath("images"), "the images scope must be set to define which images this rule applies to"))
 	}
-	result = append(result, validateSignatureRules(ctx, aiar.Signatures)...)
+	result = append(result, validateSignatureRules(ctx, aiar.ImageSelector.Signatures)...)
 	return
 }
 
@@ -24,8 +24,8 @@ func (s *Validator) ValidateUpdate(ctx context.Context, obj, old runtime.Object)
 	return s.Validate(ctx, obj)
 }
 
-func validateSignatureRules(ctx context.Context, sigRules internalv1.ImageAllowRuleSignatures) (result field.ErrorList) {
-	for i, rule := range sigRules.Rules {
+func validateSignatureRules(ctx context.Context, sigRules []internalv1.SignatureRules) (result field.ErrorList) {
+	for i, rule := range sigRules {
 		if len(rule.SignedBy.AnyOf) == 0 && len(rule.SignedBy.AllOf) == 0 {
 			result = append(result, field.Invalid(field.NewPath("signatures").Index(i).Child("signedBy"), rule.SignedBy, "must not be empty (at least one of anyOf or allOf must be specified)"))
 		}
